@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.123456789';
+our $VERSION = '0.14';
 use 5.006;
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ use Time::HiRes qw(gettimeofday);
 use Terse::WebSocket;
 use Want qw/want/;
 use Digest::SHA;
+use URI;
 use Struct::WOP qw/all/ => { type => ['UTF-8'], destruct => 1 };
 
 our ($JSON, %PRIVATE);
@@ -241,6 +242,18 @@ sub _build_terse {
 		return $t->_response($t->response);
 	}
 
+	$t->{redirect} = sub {
+		my ($self, $url, $response) = @_;
+		$url = URI->new($url);
+		$url->query_form( $url->query_form, %{$response || {}});
+		use Data::Dumper;
+		warn Dumper $url->as_string;
+		$self->response->status_code = 302;
+		$self->response->message = 'Found';
+		$self->headers->Location = $url->as_string;
+		return $self;
+	};
+
 	$t->{websocket} = sub {
 		my ($self, %args) = @_;
 		my $websocket = $t->{_websocket_class}->new($self);
@@ -396,7 +409,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.123456789
+Version 0.14
 
 =cut
 
@@ -454,6 +467,15 @@ Version 0.123456789
 		);
 	}
 
+	sub redirect {
+		my ($self, $t) = @_;
+		if ($t->params->hello) {
+			$t->redirect('', { req => 'hello_world' });
+		} else {
+			$t->redirect('https://world-wide.world/');
+		}
+	}
+
 	.... MyAPI.psgi ...
 
 	use Terse;
@@ -616,6 +638,12 @@ Delay the response for non-blocking I/O based server streaming or long-poll Come
 
 =cut
 
+=head2 redirect
+
+Redirect the response to a different url.
+
+	$terse->redirect($host_path, \%query_string);
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
